      subroutine getorbno(iyr,iday,msec,iorbno,inorad,cline1,cline2)
c
c  Orbit number fraction is computed by first computing true
c  anomaly instead of mean anomaly, and adding to the argument
c  of perigee. 
c
c Revision 1.4  1994/07/28  20:08:16  seawifst
c New version from Watson. <Mark>
c
c  NORAD Two-line elements are returned from the subroutine.
c  They are as character*69.
c
c
c.......................................................................
c Originally: rdnor.f - 20 August 92
c
c Altered and revised to: rnorad.f
c                         Kenneth S. Lambert
c                         Sea Grant - University of Maryland
c                         15 July 1993
c
c Altered and revised to: getorbit.f
c			  Watson Gregg
c			  Code 902.3
c			  NASA/GSFC
c			  December 1993
c  Modified for better orbit number calculation, using argument
c  of perigee and mean anomaly, 4/18/94, WWG
c
c  Modified to compute and use true anomaly in orbit number
c  calculation, 5/93, Robert Woodward, GSC
c
c  Adapted for use in BOBDAYS, 10.95, Fred Patt, GSC
c
c  NORAD Two-line elements are returned from the subroutine.
c  They are as character*69, 7/28/94, WWG
c
c  Given year, day of year, and time (GMT, in milliseconds), computes
c  orbit number for SeaStar/SeaWiFS, for use by the SeaWiFS Data
c  Processing System.  Requires a recent NORAD Two-Line Element
c  File for SeaStar.  I recommend that the element file be no more 
c  than 1 week old, but if the file is updated monthly only a few (1-3)
c  minutes of error should result.  A few minutes is of no 
c  consequence to HRPT stations, since the error occurs at the
c  crossing of the equator on ascending node (always night), but
c  may result in error of lunar calibration files created by the
c  SDPS.
c
c
c  Calling argument list:
c   Input
c    iyr    (I4,1) - year of data
c    iday   (I4,1) - day of year of data
c    msec   (I4,1) - time of day in milliseconds (GMT) of data
c    cline1  (A69) - first line of NORAD Two-Line Elements
c    cline2  (A69) - second line of NORAD Two-Line Elements
c   Output
c    iorbno  (I4,1) - orbit number for the data file
c    inorad  (I4,1) - error return flag:
c                         .eq. 0 - proper return
c                         .ne. 0 - error reading input format
c
c   Local Variables
c    ifound (I4,1) - flag describing whether satellite was found
c    iepyr  (I4,1) - four digit epoch year of element set
c    epday  (R8,1) - epoch day (day of year & fraction: XXX.XXXXXXXX)
c    elem   (R8,6) - element array:
c                        (1) semi-major axis (km)
c                        (2) eccentricity 
c                        (3) inclination (deg)
c                        (4) right ascension of ascending node (deg)
c                        (5) argument of perigee (deg)
c                        (6) mean anomaly (deg)
c    iorbit (i4,1) - orbit number (revolution number) for epoch
c    pi     (R8,1) - Pi
c    radeg  (R8,1) - Radians to degrees conversion factor
c    re     (R8,1) - Earth equatorial radius (km)
c    gm     (R8,1) - Earth gravitational constant (km3/s2)
c    bj2    (R8,1) - 2nd Spherical Harmonic Term
c
c.......................................................................

      save    !required for IRIX compilers 
      implicit real*8 (a-h,o-z)
      character*70 cline1,cline2
      character*128 noradf
      real*8 elem(6)
      real*8 rmanom8,reanom8,dkeplr
      data isatnum/00000/
      data imon/1/

c  Constants
      pi = dacos(-1.0D0)
      re = 6378.137D0 
      radeg = 180.0D0/pi
      gm = 398600.5D0
      bj2 = 1082.63D-6
c
c  Variable declarations
      ieof = 0
      pi2 = 2.0D0*pi                            ! 2*pi
      inorad = 0                                ! error flag
      ifound = 0

	    read(cline1(10:11),'(i2)')idyr
	    read(cline1(19:32),'(i2,f12.8)')iepyr2,epday
	    read(cline1(34:43),'(f9.8)')rndot2
	    read(cline2(8:63),'(2f9.4,i8,2f9.4)') elem(3),elem(4),iecc,
     *       elem(5),elem(6)
	    read(cline2(52:63),'(f12.8)') xmm
	    read(cline2(64:68),'(i5)')iorbit


c  Convert integer eccentricity (from assumed decimal) to real.
	elem(2) = dble(iecc)*1.0D-7

c  Compute semi-major axis using method of SGP4
	if (xmm .gt. 1.0D-10) then          !trap for divide by zero
	  xno = xmm*pi2/1440.0D0            !mean motion in radians/min
	  tothrd = 2.0D0/3.0D0
	  xincl = elem(3)/radeg             !inclination
	  eo = elem(2)
	  ck2 = abs(0.5D0*bj2)               !1/2*j2*ae**2
	  xke = sqrt(gm/re**3)*60.0D0     
	  a1 = (xke/xno)**tothrd
	  cosio = cos(xincl)
	  theta2 = cosio*cosio
	  x3thm1 = 3.0D0*theta2-1.0D0
	  eosq = eo*eo
	  betao2 = 1.0D0-eosq
	  betao = sqrt(betao2)
	  del1 = 1.5D0*ck2*x3thm1/(a1*a1*betao*betao2)
	  ao = a1*(1.0D0-del1*(0.5D0*tothrd+del1*
     *      (1.0D0+134.0D0/81.0D0*del1)))
	  delo = 1.5D0*ck2*x3thm1/(ao*ao*betao*betao2)
	  xnodp = xno/(1.0D0+delo)
	  aodp = ao/(1.0D0-delo) !semi-major axis in Earth radii
	  elem(1) = aodp*re        !semi-major axis in km
	else
	  inorad = 2
	endif
c        write(6,*)'semi-major axis = ',elem(1)
c  Compute period using method of Casey and Way, 1991 (IEEE Trans.
c   Geoscience and Remote Sensing)
        dsma2 = elem(1)*elem(1)
        dsma3 = dsma2*elem(1)
        classpd = 2.0*pi*sqrt(dsma3/gm)   !classical period
        cosarg = 4.0D0*cosio*cosio - 1.0
        pcorr = 1.0 - 3.0/2.0*bj2*re*re/dsma2*cosarg
        pdsec = classpd*pcorr
c        write(6,*)'pdsec = ',pdsec
c
c  Output iepyr as four digits, keep within range of 1950 - 2049
	if (iepyr2 .lt. 50) then
	  iepyr = 2000 + iepyr2
	else
	  iepyr = 1900 + iepyr2
	endif
c
c  Convert to Julian day
c   Compute floating point days since Jan 1.5, 2000
c    Note that the Julian day starts at noon on the specified date
        sec = msec*0.001D0
        tdata = jd(iyr,imon,iday) - 2451545.0D0 
     *          + (sec-43200.D0)/86400.D0
c        write(6,*)'iyr,iday,msec,sec,tdata = ',iyr,iday,msec,sec,tdata
        iepday = epday
        fracday = epday - iepday
        sec = fracday*86400.0D0
        tepoch = jd(iepyr,imon,iepday) - 2451545.0D0 
     *           + (sec-43200.D0)/86400.D0
c  Compute orbit number as function of time difference
c  New as of May, 1994 -- use true anomaly instead of mean anomaly
c        fracorb = (elem(5) + elem(6))/360.0D0
        rmanom8 = elem(6)/radeg   !mean anomaly in radians
        reanom8 = dkeplr(rmanom8,elem(2))  !eccentric anomaly
        a = ((1-elem(2))/(1+elem(2)))**0.5
        rtanom = 2.0 * datan(dtan((reanom8/2.0)/a)) * radeg  !true anom.
        if (rtanom .lt. .0)rtanom = rtanom + 360.0
        fracorb = (elem(5) + rtanom)/360.0D0
d        if (fracorb .ge. 1.0D0)then
d         rorbit = iorbit + (fracorb-1.0D0)
d        else
         rorbit = iorbit + fracorb
d        endif
        diff = (tdata-tepoch)*86400.0D0
        rorb = diff/pdsec + rorbit
        iorbno = rorb

      return
      end
c
c ******************************************************************
